* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Collibra Integration](https://help.sap.com/docs/leanix/ea/collibra-integration)
  * Conceptual Data Layer Mapping from Collibra to SAP …
